@@ -7,7 +7,8 @@ class AutoInjectMiddleware:
     def __init__(self, wsgi_app_callback):
         self._app_call = wsgi_app_callback
 
-    @injector.with_contextvars()
+    # NB: In debug mode, flask causes this error
+    @injector.with_contextvars(suppress_exit_warning=True)
     def wsgi_app(self, *args, **kwargs):
         return self._app_call(*args, **kwargs)
 
